@@ -5,9 +5,16 @@ pycraigslist.exceptions
 Contains the set of pycraigslist's exceptions.
 """
 
+from requests.exceptions import ConnectionError
 
-class MaximumRequestsError(Exception):
-    """Exceeds maximum get requests."""
+
+class HTTPError(Exception):
+    """An HTTP error occurred."""
+
+    def __init__(self, status_code, detail):
+        self.status_code = status_code
+        self.detail = detail
+        super().__init__("%s %s" % (self.status_code, self.detail))
 
 
 class InvalidFilterValue(ValueError):
