@@ -7,13 +7,13 @@ Tests non-querying pycraigslist attributes, instance, and class methods.
 
 from pytest import mark
 
-import specs
+import params
 
 # Leave imported for `test_valid_subclasses_from_categories`.
 import pycraigslist
 
 
-@mark.parametrize("parent", specs.obj.pycraigslist_parents)
+@mark.parametrize("parent", params.obj.pycraigslist_parents)
 def test_dtype_get_filters(parent):
     """Tests instance method `get_filters()` returns dict object,
     i.e. a reference for its query filters."""
@@ -21,14 +21,14 @@ def test_dtype_get_filters(parent):
     assert isinstance(listings.get_filters(), dict)
 
 
-@mark.parametrize("parent", specs.obj.pycraigslist_parents)
+@mark.parametrize("parent", params.obj.pycraigslist_parents)
 def test_dtype_get_categories(parent):
     """Tests class method `get_categories()` returns dict object,
     i.e. a reference for its subclass modules."""
     assert isinstance(parent.get_categories(), dict)
 
 
-@mark.parametrize("parent", specs.obj.pycraigslist_parents)
+@mark.parametrize("parent", params.obj.pycraigslist_parents)
 def test_valid_subclasses_from_categories(parent):
     """Tests every subclass method suggested in `get_categories()` is a valid object."""
     parent_class_str = str(parent).split("'")[1]
@@ -39,7 +39,7 @@ def test_valid_subclasses_from_categories(parent):
     assert True
 
 
-@mark.parametrize("parent", specs.obj.pycraigslist_parents)
+@mark.parametrize("parent", params.obj.pycraigslist_parents)
 def test_dtype_count(parent):
     """Tests attribute `count` returns int, i.e. the number of posts
     in the instance's query."""
@@ -47,7 +47,7 @@ def test_dtype_count(parent):
     assert isinstance(listings.count, int)
 
 
-@mark.parametrize("parent", specs.obj.pycraigslist_parents)
+@mark.parametrize("parent", params.obj.pycraigslist_parents)
 def test_dtype_url(parent):
     """Tests attribute `url` returns str object, i.e. the instance's
     query url."""
